@@ -5,7 +5,7 @@ __all__ = ['tty',     # libgtktty
 	   'applet',  # panel applets
 	   'capplet', # control center capplets
 	   'config', 'file', 'help', 'history',
-	   'metadata', 'mime', 'score', 'url'] # libgnome
+	   'metadata', 'mime', 'score', 'url', 'util'] # libgnome
 
 # set app_id and app_version where other modules can find it easily ...
 
@@ -24,8 +24,3 @@ app_version = "0.0"
 
 gnomelib_init_called = 0
 gnome_init_called = 0
-
-if vars().has_key('__'):
-	# ni has been used -- move all symbols to module __
-	exec "from __init__ import *" in __.__dict__
-
